<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="es" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation type="vanished">Acerca de</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Categoría:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Iniciar torrent</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>No comprobar hash</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Crear subcarpeta</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Modo de administración del torrent:</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Todos</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Sin categorizar</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Agregar categoría...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Eliminar categoría</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Eliminar categorías sin utilizar</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Continuar torrents</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Pausar torrents</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Eliminar torrents</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Nueva categoría</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>Editar categoría...</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>Salir de qBittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Solamente un enlace por línea</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>El límite de la tasa de subida debe ser mayor que 0 o estar inhabilitado.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>El límite de la tasa de descarga debe ser mayor que 0 o estar inhabilitado.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>El límite alternativo de la tasa de subida debe ser mayor que 0 o estar inhabilitado.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>El límite alternativo de la tasa de descarga debe ser mayor que 0 o estar inhabilitado.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>El número máximo de descargas activas debe ser mayor que -1.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>El número máximo de subidas activas debe ser mayor que -1.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>El número máximo de torrents activos debe ser mayor que -1.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>El número máximo del limite de conexiones debe ser mayor que 0 o estar inhabilitado.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>El número máximo del limite de conexiones por torrent debe ser mayor que 0 o estar inhabilitado.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>El número máximo de puestos de subida por torrent debe ser mayor que 0 o estar inhabilitado.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Error al guardar las preferencias del programa, imposible conectar a qBittorrent.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: #qbittorrent en Freenode</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>El limite de ratio debe estar entre 0 y 9998</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>El limite de tiempo de sembrado debe estar entre 0 y 525600 minutos.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>El puerto utilizado para conexiones entrantes debe estar comprendido entre 1 y 65535.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>El puerto utilizado para la interfaz Web debe estar comprendido entre 1 y 65535.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Error al iniciar sesión, imposible conectar a qBittorrent.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Nombre de usuario o contraseña inválidos.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Iniciar sesión</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Autores originales</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Agregar</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Subir Torrents</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Guardar los archivos en:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Cookie:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Escribir carpeta aquí</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Más Información</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Información sobre certificados</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Establecer destino</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>Tasa límite de subida</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>Tasa límite de bajada...</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Renombrar torrent</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Otro...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Lunes</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Martes</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Miércoles</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Jueves</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Viernes</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Domingo</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Descargar torrents desde sus URL o enlaces magnet</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Subir torrent local</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>¿Seguro que desea eliminar los torrents seleccionados de la lista de transferencias?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>Imposible conectar a qBittorrent</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>El máximo número de puestos de subida debe ser mayor que 0 o estar inhabilitado.</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>Nombre de categoría invalido:\nPor favor no use caracteres especiales para el nombre de la categoría.</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>No se pudo crear la categoría</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>El límite de la tasa de subida debe ser mayor que 0.</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>Espacio libre: %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>El tiempo de inactividad del torrent debe ser mayor que 0.</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>Administración de guardado</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation>El límite de la tasa de descarga debe ser mayor que 0.</translation>
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>qBittorrent ha sido cerrado</translation>
    </message>
    <message>
        <source>Open documentation</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Register to handle magnet links...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Unable to add peers. Please ensure you are adhering to the IP:port format.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation>¡Es necesario JavaScript! Debes habilitar JavaScript para que la Web UI funcione correctamente.</translation>
    </message>
    <message>
        <source>Name cannot be empty</source>
        <translation>El nombre no puede estar vacío</translation>
    </message>
    <message>
        <source>Name is unchanged</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Failed to update name</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Herramientas</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Archivo</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Opciones...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Barra de herramientas</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Barra de estado</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Velocidad en la barra de título</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Donar!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Reanudar todos</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Estadísticas</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Pausar todos</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Agregar archivo torrent...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Documentación</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Agregar enlace torrent...</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Límite de velocidad de subida global</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Límite de velocidad de descarga global</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>¿Está seguro de que quiere cerrar qBittorrent?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[B: %1, S: %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>Límites de velocidad alternativos</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>Motor de búsqueda</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>Filtrar lista de torrents...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>Transferencias</translation>
    </message>
    <message>
        <source>Move up in the queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move Up Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Bottom of Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move to the bottom of the queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Top of Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move Down Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move down in the queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move to the top of the queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Your browser does not support this feature</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>To use this feature, the WebUI needs to be accessed over HTTPS</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Connection status: Firewalled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Connection status: Connected</source>
        <translation>Estado de la conexión: Conectado</translation>
    </message>
    <message>
        <source>Alternative speed limits: Off</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download speed icon</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Connection status</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Alternative speed limits: On</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload speed icon</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Connection status: Disconnected</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Descargas</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Conexión</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocidad</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Interfaz Web</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Idioma</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Idioma de la interfaz:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>Notificarme por correo electrónico de la finalización de las descargas</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Ejecutar un programa externo al completar el torrent</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>Filtrado IP</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>Programar el uso de límites alternativos</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Torrents en cola</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>Agregar automáticamente estos trackers a las descargas:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>interfaz Web (Control remoto)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>Direcciones IP:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Dominios de servidor:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>Usar HTTPS en lugar de HTTP</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>Eludir la autenticación para clientes en localhost</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>Eludir la autenticación para clientes en la lista blanca de subredes IP</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>Actualizar mi nombre de dominio dinámico</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Mantener torrents incompletos en:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>Copiar archivos .torrent en:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Copiar archivos .torrent de descargas finalizadas a:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Reservar el espacio en el disco para todos los archivos</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>Agregar la extensión .!qB a los archivos incompletos</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>Agregar automáticamente los torrents de:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>Servidor SMTP:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>El servidor requiere una conexión segura (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autenticación</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nombre de usuario:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Contraseña:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Protocolo Activado:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP y μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Puerto de escucha</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Puerto utilizado para conexiones entrantes:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>Usar reenvío de puertos UPnP / NAT-PMP de mi router</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Usar un puerto diferente en cada inicio</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Límites de conexión</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Máximo de conexiones por torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Máximo de conexiones totales:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Máximo de puestos de subida por torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Máximo total de puestos de subida:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Servidor proxy</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(Ninguno)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Puerto:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Usar proxy para las conexiones a los pares</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Usar proxy solo para torrents</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Ruta del filtro (.dat, .p2p, .p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>Direcciones IP prohibidas manualmente...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>Aplicar a los trackers</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Limites globales de velocidad</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Subida:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Bajada:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Límites de velocidad alternativos</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>Desde las:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>Hasta:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Cuándo:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Todos los días</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Días laborales</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Fines de semana</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Configuración de los limites</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>Aplicar límite para el exceso de transporte (Overhead)</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Aplicar límite para conexiones µTP</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Privacidad</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>Activar DHT (red descentralizada) para encontrar más pares</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Habilitar intercambio de pares (PeX) para encontrar más pares</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Habilitar busqueda local de pares para encontrar más pares</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Modo de cifrado:</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Exigir cifrado</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Deshabilitar cifrado</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>Activar modo anónimo</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>Máximo de descargas activas:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>Máximo de subidas activas:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>Máximo de torrents activos:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>No contar torrents lentos en estos límites</translation>
    </message>
    <message>
        <source>then</source>
        <translation>luego</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>Usar UPnP / NAT-PMP para redirigir el puerto de mi router</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Certificado:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Clave:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Registro</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Nombre de dominio:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Parámetros soportados (sensible a mayúsculas):</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: Nombre del torrent</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: Categoría</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: Ruta del contenido (misma ruta que la raíz para torrents muilti-archivo)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: Ruta Raíz (primer subdirectorio del torrent)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: Ruta de destino</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: Cantidad de archivos</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: Tamaño del torrent (bytes)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: Tracker actual</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: Info hash</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>Consejo: Encapsula el parámetro con comillas para evitar que el texto sea cortado en un espacio (ej: "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>El nombre de usuario de la interfaz Web debe ser de al menos 3 caracteres.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>La contraseña de Interfaz de Usuario Web debe ser de al menos 6 caracteres.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutos</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>Activar protección de clickjacking</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>Activar protección CSRF (Cross-site Request Forgery)</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>Después eliminar el archivo .torrent</translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>Umbral de vel. de descarga:</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>Umbral de vel. de subida:</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>Cambiar contraseña actual</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>Usar la interfaz Web alternativa</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>Ubicación de guardado predeterminada:</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>La ubicación de los archivos de la Interfaz de Usuario Web alternativa no puede estar vacía.</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>No iniciar las descargas de forma automática</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>Cambiar torrent a modo manual</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>Cuando cambia la categoría del torrent:</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>Reubicar los torrents afectados</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>Aplicar límite a los pares en LAN</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 significa ilimitado</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>Reubicar torrent</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>Cuando la ubicación de guardado predeterminada cambia:</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>Habilitar la validación del encabezado del Host</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Seguridad</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>Cuando cambia la ruta de destino de la categoría:</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>Crear una sub-carpeta para torrents con múltiples archivos</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>segundos</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>Cambiar los torrents afectados a modo manual</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>Ubicación de archivos:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>Temporizador de inactividad de Torrent:</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>Administración de Torrents predeterminada:</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>Al agregar un torrent</translation>
    </message>
    <message>
        <source>Info: The password is saved unencrypted</source>
        <translation>Información: La contraseña se guarda sin cifrar</translation>
    </message>
    <message>
        <source>μTP-TCP mixed mode algorithm:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload rate based</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%G: Tags (separated by comma)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Socket backlog size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable super seeding for torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Prefer TCP</source>
        <translation>Preferir TCP</translation>
    </message>
    <message>
        <source>Outstanding memory when checking torrents:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Anti-leech</source>
        <translation>Anti-leech</translation>
    </message>
    <message>
        <source>Enable OS cache:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When ratio reaches</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When seeding time reaches</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Allow multiple connections from the same IP address:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>File pool size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Any interface</source>
        <translation>Cualquier interfaz</translation>
    </message>
    <message>
        <source>Always announce to all tiers:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Embedded tracker port:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Optional IP Address to bind to (requires restart):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Fastest upload</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Pause torrent</source>
        <translation>Pausar torrent</translation>
    </message>
    <message>
        <source>Remove torrent and its files</source>
        <translation>Eliminar el torrent y sus archivos</translation>
    </message>
    <message>
        <source>qBittorrent Section</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Send buffer watermark factor:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>libtorrent Section</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Coalesce reads &amp; writes:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Outgoing ports (Min) [0: Disabled]:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>IP Address to report to trackers (requires restart):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Recheck torrents on completion:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Allow encryption</source>
        <translation>Permitir el cifrado</translation>
    </message>
    <message>
        <source>Send upload piece suggestions:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Disk cache:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable embedded tracker:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Outgoing ports (Max) [0: Disabled]:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Asynchronous I/O threads:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>s</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Send buffer watermark:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Disk cache expiry interval:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Peer proportional (throttles TCP)</source>
        <translation>Proporcional a los pares (ahoga el TCP)</translation>
    </message>
    <message>
        <source>Fixed slots</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avanzado</translation>
    </message>
    <message>
        <source>min</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload choking algorithm:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeding Limits</source>
        <translation>Límite de siembra</translation>
    </message>
    <message>
        <source>KiB</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Round-robin</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload slots behavior:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Network Interface (requires restart):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>MiB</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Send buffer low watermark:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Save resume data interval:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Always announce to all trackers in a tier:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Session timeout:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Resolve peer countries:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>ban for:</source>
        <translation>vetar por:</translation>
    </message>
    <message>
        <source>Use piece extent affinity (requires libtorrent &gt;= 1.2.2):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Stop tracker timeout:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Ban client after consecutive failures:</source>
        <translation>Vetar el cliente después de fracasos consecutivos:</translation>
    </message>
    <message>
        <source>Enable cookie Secure flag (requires HTTPS)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>UPnP lease duration [0: Permanent lease]:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Header: value pairs, one per line</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add custom HTTP headers</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Puerto</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Banderas</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Conexión</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Cliente</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Progreso</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Vel. Descarga</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Vel. Subida</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Descargado</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Subido</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Importancia</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Archivos</translation>
    </message>
    <message>
        <source>Ban peer permanently</source>
        <translation>Vetar al par de forma permanente</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently ban the selected peers?</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy IP:port</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add a new peer...</source>
        <translation>Añadir un nuevo par...</translation>
    </message>
    <message>
        <source>Country/Region</source>
        <translation>País/Región</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Normal</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Alta</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Máxima</translation>
    </message>
    <message>
        <source>Mixed</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Do not download</source>
        <translation>No descargar</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Trackers</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Pares</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>Fuentes HTTP</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Contenido</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Descargado:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Transferencia</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Tiempo activo:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>Tiempo restante:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Subido:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Semillas:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>Velocidad de descarga:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Velocidad de subida:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Pares:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Límite de descarga:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Límite de subida:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Desperdiciado:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Conexiones:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Comentario:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Ratio de compartición:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Anunciar en:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Ultima vez visto completo:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Tamaño total:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Piezas:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Creado por:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Agregado el:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Completado el:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Creado el:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Hash del torrent:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Ruta de destino:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (tienes %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (%2 en esta sesión)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (%2 máx)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (%2 total)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (%2 prom.)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>Límite de bajada:</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>Límite de subida:</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Prioridad</translation>
    </message>
    <message>
        <source>Filter files...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Rename...</source>
        <translation>Renombrar...</translation>
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Carpeta Monitoreada</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Cambiar ubicación de guardado</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Carpeta Monitoreada</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Ubicación de guardado predeterminada</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Estadísticas</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Estadísticas del usuario</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Estadísticas de la caché</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Uso de la caché de lectura:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Tiempo promedio en cola:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>Pares conectados:</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>Ratio de comparticíon:</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>Total bajado:</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>Desperdicio de sesión:</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>Total subido:</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>Tamaño total del buffer:</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Estadísticas de rendimiento</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>Trabajos de I/O en cola:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Sobrecarga de la caché de escritura:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Sobrecarga de la caché de lectura:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Tamaño total de cola:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 nodos</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Todos (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>Descargando (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>Sembrando (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Completados (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Continuados (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>Pausados (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Activos (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Inactivos (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>Con errores (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Todos (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>Descargando (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>Sembrando (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Completados (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>Pausados (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Continuados (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Activos (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Inactivos (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>Con errores (%1)</translation>
    </message>
    <message>
        <source>Stalled Uploading (%1)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Stalled Downloading (%1)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Stalled Downloading (0)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Stalled (0)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Stalled Uploading (0)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Stalled (%1)</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    </context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Tamaño</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Progreso</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Semillas</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Pares</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Vel. descarga</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Vel. Subida</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Ratio</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>Tiempo Restante</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categoría</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Etiquetas</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Agregado</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Completado</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Tracker</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Límite descarga</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Límite Subida</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Descargado</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Subido</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Desc. Sesión</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Sub. Sesión</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Restante</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Tiempo Activo</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Ruta Destino</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Completado</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Límite de ratio</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Visto Completo</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Última Actividad</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Tamaño Total</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Pares</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Mensaje</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Bajado</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>URL del tracker:</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Actualizando...</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>Trabajando</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Deshabilitado</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>Todavía no contactado</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>Semillas</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>No funciona</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>Copiar URL del tracker</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>Agregar nuevo tracker...</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>Editar URL del tracker:</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>Editando tracker</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>Pares</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>Eliminar tracker</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>Restante</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tier</source>
        <translation>Nivel</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>Prioridad de descarga</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Progress</source>
        <translation>Progreso</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Diálogo para agregar trackers</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Lista de trackers a agregar (uno por línea):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>hace %1</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>Reservando espacio</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pausados</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Completado</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>Moviendo</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>[F] Sembrando</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>Sembrando</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>En cola</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>Con errores</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>[F] Descargando</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>Descargando metadatos</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>Verificando</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>Faltan archivos</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>En cola para su verificación</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Descargando</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>Verificando datos de continuación</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>Detenido</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Categorías</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Etiquetas</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Límite de velocidad de descarga del torrent</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Límite de velocidad de subida del torrent</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Forzar continuación</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Límitar ratio de compartición...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Tasa límite de subida...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Tasa límite de descarga...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Mover arriba</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Mover abajo</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>Mover al principio</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>Mover al final</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Establecer destino...</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Descargar antes primeras y últimas partes</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Administración automática de torrents</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categoría</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Nueva...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Descategorizar</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Forzar verificación de archivo</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Modo supersiembra</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Renombrar...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Descargar en orden secuencial</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>Forzar verificación</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Nueva categoría</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Ubicación</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>Nuevo nombre</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Establecer destino</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>Forzar recomunicación</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>Editar categoría</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>Ruta de destino</translation>
    </message>
    <message>
        <source>Comma-separated tags:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add Tags</source>
        <translation>Añadir etiquetas</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Magnet link</source>
        <translation>Enlace magnético</translation>
    </message>
    <message>
        <source>Hash</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove All</source>
        <translation>Eliminar todo</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Queue</source>
        <translation>Cola</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Añadir...</translation>
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Límites de ratio de subida/descarga</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Usar límite de ratio global</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>Sin límites de ratio</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>Establecer límite de ratio en</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>ratio</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutos</translation>
    </message>
</context>
<context>
    <name>about</name>
    </context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Confirmar eliminación</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Eliminar también los archivos del disco duro</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>Confirmar borrado - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>Descargar de URLs</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Descargar</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>Agregar enlaces torrent</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1h %2m</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1d %2h</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Desconocido</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt;1m</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1m</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>Ruta de destino vacía</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>Ruta del plugin:</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>URL o directorio local</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>Instalar plugin</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>Semillas:</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>Todos los plugins</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Tamaño:</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>Plugins de búsqueda...</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>Todas</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>Buscar en:</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>Resultados (mostrando</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtro</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>Solo nombres de Torrent</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>Solo habilitados</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>de</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>En todas partes</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>Desinstalar</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>Instalar nuevo plugin</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>Puedes obtener nuevos plugins de motores de busqueda aquí:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>Plugins de búsqueda instalados:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Habilitado</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>Advertencia: Asegúrese de cumplir con las leyes de copyright de su país cuando descarga torrents de estos motores de búsqueda. </translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Buscar actualizaciones</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>Plugins de búsqueda</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>Pares</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Motor de búsqueda</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>Semillas</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Habilitado</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versión</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <source>No</source>
        <translation>No</translation>
    </message>
</context>
<context>
    <name>PeersAdditionDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Add Peers</source>
        <translation>Añadir pares</translation>
    </message>
    <message>
        <source>List of peers to add (one IP per line):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Format: IPv4:port / [IPv6]:port</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TagFilterWidget</name>
    <message>
        <source>New Tag</source>
        <translation>Nueva etiqueta</translation>
    </message>
    <message>
        <source>Add tag...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Eliminar torrents</translation>
    </message>
    <message>
        <source>Tag:</source>
        <translation>Etiqueta:</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Pausar torrents</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove unused tags</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Invalid tag name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove tag</source>
        <translation>Eliminar etiqueta</translation>
    </message>
</context>
<context>
    <name>TagFilterModel</name>
    <message>
        <source>All</source>
        <translation>Todo</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <source>Bug Tracker:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>Foro:</translation>
    </message>
    <message>
        <source>E-mail:</source>
        <translation>E-mail:</translation>
    </message>
    <message>
        <source>Current maintainer</source>
        <translation>Mantenedor actual</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Greece</source>
        <translation>Grecia</translation>
    </message>
    <message>
        <source>Special Thanks</source>
        <translation>Agradecimientos especiales</translation>
    </message>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <source>About qBittorrent</source>
        <translation>Acerca de qBittorrent</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Translators</source>
        <translation>Traductores</translation>
    </message>
    <message>
        <source>qBittorrent was built with the following libraries:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Nationality:</source>
        <translation>Nacionalidad:</translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Software Used</source>
        <translation>Software utilizado</translation>
    </message>
    <message>
        <source>The free IP to Country Lite database by DB-IP is used for resolving the countries of peers. The database is licensed under the Creative Commons Attribution 4.0 International License</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>OptionDialog</name>
    <message>
        <source>All addresses</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All IPv6 addresses</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All IPv4 addresses</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>SearchJobWidget</name>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Download</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Description page URL</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Open description page</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download link</source>
        <translation>Enlace de descarga</translation>
    </message>
</context>
<context>
    <name>TorrentContentTreeView</name>
    <message>
        <source>Renaming</source>
        <translation>Restante</translation>
    </message>
    <message>
        <source>New name:</source>
        <translation>Nuevo nombre:</translation>
    </message>
</context>
</TS>